PartialControl

Struct PartialControl 

pub struct PartialControl<const enable_interrupt: bool, const reset_rx_fifo: bool, const reset_tx_fifo: bool> { /* private fields */ }
Builder struct for partial initialization of Control .

Implementations

Source

impl<const reset_rx_fifo: bool, const reset_tx_fifo: bool> PartialControl<false, reset_rx_fifo, reset_tx_fifo>

pub const fn with_enable_interrupt( &self, value: bool, ) -> PartialControl<true, reset_rx_fifo, reset_tx_fifo>

Enable interrupt bit.

Source

impl<const enable_interrupt: bool, const reset_tx_fifo: bool> PartialControl<enable_interrupt, false, reset_tx_fifo>

pub const fn with_reset_rx_fifo( &self, value: bool, ) -> PartialControl<enable_interrupt, true, reset_tx_fifo>

Reset RX FIFO.

Source

impl<const enable_interrupt: bool, const reset_rx_fifo: bool> PartialControl<enable_interrupt, reset_rx_fifo, false>

pub const fn with_reset_tx_fifo( &self, value: bool, ) -> PartialControl<enable_interrupt, reset_rx_fifo, true>

Reset TX FIFO.

Source

impl PartialControl<true, true, true>

pub const fn build(&self) -> Control

Builds the bitfield from the values passed into this builder.

Every field must be set on PartialControl to be able to build a Control .