RxFifo

Struct RxFifo 

pub struct RxFifo { /* private fields */ }
RX FIFO register.

Implementations

Source

impl RxFifo

pub const ZERO: Self

Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].

pub const fn raw_value(&self) -> u32

Returns the underlying raw value of this bitfield

pub const fn new_with_raw_value(value: u32) -> RxFifo

Creates a new instance of this bitfield with the given raw value.

No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.

pub const fn data(&self) -> u8

Data which can be read.