TxAsync

Struct TxAsync 

pub struct TxAsync { /* private fields */ }
Asynchronous TX driver.

Implementations

Source

impl TxAsync

pub unsafe fn new(tx: Tx, waker_idx: usize) -> Result<Self, InvalidWakerIndex>

Create a new asynchronous TX structure.

Safety

The user MUST ensure that the Drop method of all futures generated with this driver is called on transfer cancellation. By default, this does not require any special handling.

pub fn write<'buf>(&mut self, buf: &'buf [u8]) -> TxFuture<'_, 'buf>

Write a buffer asynchronously.

This implementation is not side effect free, and a started future might have already written part of the passed buffer.

pub fn release(self) -> Tx

Release the owned TX structure.