pub struct RxFifo { /* private fields */ }Expand description
RX FIFO register.
Implementations
Sourceimpl RxFifo
impl RxFifo
Sourcepub const ZERO: Self
pub const ZERO: Self
Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].
Sourcepub const fn new_with_raw_value(value: u32) -> RxFifo
pub const fn new_with_raw_value(value: u32) -> RxFifo
Creates a new instance of this bitfield with the given raw value.
No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.